%global debug_package %{nil}
%global git_commit f734724


Name:       knative-client
Version:    1.17.0
Release:    1%{?dist}
Summary:    Client tool for creating Knative resources
License:    Apache-2.0
URL:        https://knative.dev
Source0:    https://github.com/knative/client/archive/refs/tags/knative-v%{version}.tar.gz
Source1:    client-knative-v%{version}-vendored-deps.tar.zst
Source2:    bundled.inc

BuildRequires:  golang
%include        %SOURCE2

Recommends: %{name}-doc

%description
kn provides a quick and easy interface for creating Knative resources
such as services and event sources, without the need to create or
modify YAML files directly. kn also simplifies completion of otherwise
complex procedures such as autoscaling and traffic splitting.


%package doc
Summary:    Knative CLI documentation
Enhances:   %{name} = %{version}-%{release}
BuildArch:  noarch

%description doc
Knative CLI documentation


%prep
%autosetup -n client-knative-v%{version}
tar -xf %SOURCE1 --strip-components=1


%build
export build_date=$(date +'%F %T')
export GO_LDFLAGS="\
    -X 'knative.dev/client/pkg/commands/version.BuildDate=${build_date}'\
    -X 'knative.dev/client/pkg/commands/version.Version=%{version}'\
    -X 'knative.dev/client/pkg/commands/version.GitRevision=%{git_commit}'"
export CGO_ENABLED=0
go build -p 4 -v -ldflags "-s -w ${GO_LDFLAGS}" -mod=vendor -o ./kn ./cmd/kn

for SYS_SHELL in bash fish zsh; do
    ./kn completion ${SYS_SHELL} > kn.${SYS_SHELL}
done


%install
install -Dv -m 0755 kn %{buildroot}%{_bindir}/kn
install -dv -m 0755 %{buildroot}%{_datadir}/doc/knative-client
cp -rv docs %{buildroot}%{_datadir}/doc/knative-client/documentation

install -m 0755 -vd         %{buildroot}%{bash_completions_dir}
install -m 0644 -vp kn.bash %{buildroot}%{bash_completions_dir}/
install -m 0755 -vd         %{buildroot}%{fish_completions_dir}
install -m 0644 -vp kn.fish %{buildroot}%{fish_completions_dir}/
install -m 0755 -vd         %{buildroot}%{zsh_completions_dir}
install -m 0644 -vp kn.zsh  %{buildroot}%{zsh_completions_dir}/


%files
%doc README.md CHANGELOG.adoc
%license LICENSE
%{_bindir}/kn
%{bash_completions_dir}/kn.bash
%{fish_completions_dir}/kn.fish
%{zsh_completions_dir}/kn.zsh

%files doc
%{_datadir}/doc/knative-client/documentation


%changelog
* Thu Jan 23 2025 Mike Rochefort <mroche@omenos.dev> - 1.17.0-1
- Update to v1.17.0

* Sun Aug 25 2024 Mike Rochefort <mroche@omenos.dev> - 1.15.0-1
- Update to v1.15.0

* Sat Apr 27 2024 Mike Rochefort <mroche@omenos.dev> - 1.14.0-1
- Update to v1.14.0

* Wed Jan 24 2024 Mike Rochefort <mroche@omenos.dev> - 1.13.0-1
- Update to v1.13.0

* Mon Nov 27 2023 Mike Rochefort <mroche@omenos.dev> - 1.12.0-1
- Update to v1.12.0

* Tue Oct 31 2023 Mike Rochefort <mroche@omenos.dev> - 1.11.2-1
- Update to v1.11.2

* Sat Oct 21 2023 Mike Rochefort <mroche@omenos.dev> - 1.11.1-1
- Update to v1.11.1

* Sat Oct 14 2023 Mike Rochefort <mroche@omenos.dev> - 1.11.0-2
- Rebuild with Go 1.21.3

* Thu Aug 03 2023 Mike Rochefort <mroche@omenos.dev> - 1.11.0-1
- Update to v1.11.0

* Sat Apr 29 2023 Mike Rochefort <mroche@omenos.dev> - 1.10.0-1
- Update to v1.10.0

* Mon Mar 27 2023 Mike Rochefort <mroche@omenos.dev> - 1.9.2-1
- Update to v1.9.2

* Wed Mar 08 2023 Mike Rochefort <mroche@omenos.dev> - 1.9.1-1
- Update to v1.9.1

* Fri Jan 27 2023 Mike Rochefort <mroche@omenos.dev> - 1.9.0-1
- Update to v1.9.0

* Thu Oct 20 2022 Mike Rochefort <mroche@redhat.com> - 1.8.1-1
- Update to v1.8.1

* Wed Oct 19 2022 Mike Rochefort <mroche@redhat.com> - 1.8.0-1
- Update to v1.8.0

* Tue Oct 11 2022 Mike Rochefort <mroche@redhat.com> - 1.7.1-1
- Update to v1.7.1

* Wed Aug 24 2022 Mike Rochefort <mroche@redhat.com> - 1.7.0-1
- Update to v1.7.0

* Wed Aug 17 2022 Mike Rochefort <mroche@redhat.com> - 1.6.1-1
- Update to v1.6.1

* Wed Jul 13 2022 Mike Rochefort <mroche@redhat.com> - 1.6.0-1
- Update to v1.6.0

* Wed Jun 01 2022 Mike Rochefort <mroche@redhat.com> - 1.5.0-1
- Update to v1.5.0

* Tue May 17 2022 Mike Rochefort <mroche@redhat.com> - 1.4.1-1
- Update to v.1.4.1

* Wed Apr 20 2022 Mike Rochefort <mroche@redhat.com> - 1.4.0-1
- Update to v.1.4.0

* Wed Mar 09 2022 Mike Rochefort <mroche@redhat.com> - 1.3.0-2
- Remove vendored deps tarball

* Wed Mar 09 2022 Mike Rochefort <mroche@redhat.com> - 1.3.0-1
- Update to v1.3.0

* Sat Feb 12 2022 Mike Rochefort <mroche@redhat.com> - 1.2.0-1
- Build v1.2.0
